@@ -362,6 +362,7 @@ our %servers = qw(
     WEDDING         whois-dub.mm-registry.com
     WORK            whois-dub.mm-registry.com
     YOGA            whois-dub.mm-registry.com
+    OOO             whois-dub.mm-registry.com
 
     TV  whois.nic.tv
     WS  whois.worldsite.ws
@@ -700,6 +701,7 @@ our %servers = qw(
     SO          whois.nic.so
     BZ          whois2.afilias-grs.net
     XXX         whois.nic.xxx
+    MOSCOW      whois.nic.moscow
 );
 
 
@@ -961,6 +963,7 @@ our %notfound = (
     'whois.online.rs.corenic.net' => 'no matching objects found',
     'whois.site.rs.corenic.net'   => 'no matching objects found',
     'whois.nic.xn--80adxhks'      => 'No entries found for the selected source',
+    'whois.nic.moscow'            => 'No entries found for the selected source',
 );
 
 # Common whois stripping REs
@@ -2480,6 +2483,7 @@ our %strip = (
     'whois.online.rs.corenic.net' => [ '^%' ],
     'whois.site.rs.corenic.net'   => [ '^%' ],
     'whois.nic.xn--80adxhks'      => [ '^%' ],
+    'whois.nic.moscow'            => [ '^%' ],
 );
 
 our %exceed = (
